use yew::{function_component, html, use_state_eq, Callback, Html, UseStateHandle};
use yew_agent::reactor::ReactorProvider;

#[function_component]
pub fn Counter() -> Html {
    let count_value: UseStateHandle<u64> = use_state_eq(|| 0);

    #[cfg(feature = "frontend")]
    let callback = {
        use yew_agent::reactor::{use_reactor_bridge, ReactorEvent};

        let count_value_ = count_value.clone();
        let counter_bridge = use_reactor_bridge::<crate::frontend::worker::Counter, _>(move |ev| {
            if let ReactorEvent::Output(value) = ev {
                count_value_.set(value);
            }
        });

        Callback::from(move |_: yew::MouseEvent| {
            counter_bridge.send(());
        })
    };
    #[cfg(not(feature = "frontend"))]
    let callback = { Callback::noop() };

    html! {
        <div class="w-full h-full flex">{"Counter: "}
            <h1 class="mx-auto my-auto" onclick={callback}>{format!("{}", *count_value)}</h1>
        </div>
    }
}

#[function_component]
pub fn CounterPage() -> Html {
    html! {
        <ReactorProvider<crate::frontend::worker::Counter> path="/static/worker.js">
            <Counter />
        </ReactorProvider<crate::frontend::worker::Counter>>
    }
}
